@@ -25,7 +25,7 @@ let has_capability daemon =
   OBus_property.make p_HasCapability (proxy daemon)
 
 let get_total daemon =
-  lwt value = OBus_method.call m_GetTotal (proxy daemon) () in
+  let%lwt value = OBus_method.call m_GetTotal (proxy daemon) () in
   let value = Int32.to_int value in
   return value
 
@@ -37,7 +37,7 @@ let total_changed daemon =
     (OBus_signal.make s_TotalChanged (proxy daemon))
 
 let get_data daemon =
-  lwt data = OBus_method.call m_GetData (proxy daemon) () in
+  let%lwt data = OBus_method.call m_GetData (proxy daemon) () in
   return
     (List.map
        (fun (is_userspace, id, value, cmdline, details) -> {
