@@ -13,7 +13,7 @@ open Lwt
 open Lwt_io
 
 let ping obj msg =
-  lwt () = printlf "received: %s" msg in
+  let%lwt () = printlf "received: %s" msg in
   return msg
 
 let interface =
@@ -21,11 +21,11 @@ let interface =
     Ping_pong.Org_foo_bar.m_Ping = (fun obj msg -> ping (OBus_object.get obj) msg);
   }
 
-lwt () =
-  lwt bus = OBus_bus.session () in
+let () = Lwt_main.run begin
+  let%lwt bus = OBus_bus.session () in
 
   (* Request a name *)
-  lwt _ = OBus_bus.request_name bus "org.plop" in
+  let%lwt _ = OBus_bus.request_name bus "org.plop" in
 
   (* Create the object *)
   let obj = OBus_object.make ~interfaces:[interface] ["plip"] in
@@ -36,3 +36,4 @@ lwt () =
 
   (* Wait forever *)
   fst (wait ())
+end
